@@ -9,6 +9,8 @@
 #include <QDebug>
 #include <KCalendarCore/Sorting>
 
+#include "calendarcontroller.h"
+
 using namespace KCalendarCore;
 
 IncidenceModel::IncidenceModel(QObject *parent) :
@@ -17,7 +19,6 @@ IncidenceModel::IncidenceModel(QObject *parent) :
     m_filter_dt(QDate()),
     m_filter_hour(-1),
     m_filter_hide_completed(false),
-    m_calendar(nullptr),
     m_incidences(Incidence::List()),
     m_locale(QLocale::system()),
     m_cal_filter(new CalFilter())
@@ -28,6 +29,14 @@ IncidenceModel::IncidenceModel(QObject *parent) :
     connect(this, &IncidenceModel::filterHourChanged, this, &IncidenceModel::loadIncidences);
     connect(this, &IncidenceModel::calendarChanged, this, &IncidenceModel::loadIncidences);
     connect(this, &IncidenceModel::calendarFilterChanged, this, &IncidenceModel::loadIncidences);
+
+    m_calendar = CalendarController::instance().activeCalendar();
+
+    connect(m_calendar, &LocalCalendar::calendarChanged, this, &IncidenceModel::loadIncidences);
+    connect(m_calendar, &LocalCalendar::eventsChanged, this, &IncidenceModel::loadIncidences);
+    connect(m_calendar, &LocalCalendar::todosChanged, this, &IncidenceModel::loadIncidences);
+
+    setCalendarFilter();
 }
 
 IncidenceModel::~IncidenceModel() = default;
@@ -68,22 +77,6 @@ void IncidenceModel::setFilterHour(const int hour)
     Q_EMIT filterHourChanged();
 }
 
-LocalCalendar *IncidenceModel::calendar() const
-{
-    return m_calendar;
-}
-
-void IncidenceModel::setCalendar(LocalCalendar *calendarPtr)
-{
-    m_calendar = calendarPtr;
-    setCalendarFilter();
-
-    connect(m_calendar, &LocalCalendar::eventsChanged, this, &IncidenceModel::loadIncidences);
-    connect(m_calendar, &LocalCalendar::todosChanged, this, &IncidenceModel::loadIncidences);
-
-    Q_EMIT calendarChanged();
-}
-
 QHash<int, QByteArray> IncidenceModel::roleNames() const
 {
     return {
@@ -199,7 +192,7 @@ QVariant IncidenceModel::data(const QModelIndex &index, int role) const
     case AttendeeEmails:
         return attendeeEmails(row);
     case DisplayAttendeeEmails:
-        return attendeeEmails(row).join(QString {", "});
+        return attendeeEmails(row).join(QStringLiteral(", "));
     case IncidenceStatus:
         return m_incidences.at(row)->status();
     case OrganizerName: {
@@ -210,7 +203,7 @@ QVariant IncidenceModel::data(const QModelIndex &index, int role) const
         return QString {};
     }
     case DisplaytAttendeeNames:
-        return attendeeNames(row).join(QString {", "});
+        return attendeeNames(row).join(QStringLiteral(", "));
     default:
         return QVariant();
     }
@@ -496,13 +489,13 @@ QString IncidenceModel::eventDisplayStartEndTime(const Event::Ptr event) const
     auto endDateTime = event->dtEnd().toTimeZone(QTimeZone::systemTimeZone());
 
     if (event->allDay()) {
-        return QString("%1 %2").arg(m_locale.toString(startDateTime, "MMM d"), i18n("all-day"));
+        return QStringLiteral("%1 %2").arg(m_locale.toString(startDateTime, QStringLiteral("MMM d")), i18n("all-day"));
     }
 
     if (startDateTime.date() != endDateTime.date()) {
-        return QString("%1 %2 - %3 %4").arg(m_locale.toString(startDateTime, "MMM d"), m_locale.toString(startDateTime, "hh:mm"), m_locale.toString(endDateTime, "MMM d"), m_locale.toString(endDateTime, "hh:mm"));
+        return QStringLiteral("%1 %2 - %3 %4").arg(m_locale.toString(startDateTime, QStringLiteral("MMM d")), m_locale.toString(startDateTime, QStringLiteral("hh:mm")), m_locale.toString(endDateTime, QStringLiteral("MMM d")), m_locale.toString(endDateTime, QStringLiteral("hh:mm")));
     } else {
-        return QString("%1 - %2").arg(m_locale.toString(startDateTime, "hh:mm"), m_locale.toString(endDateTime, "hh:mm"));
+        return QStringLiteral("%1 - %2").arg(m_locale.toString(startDateTime, QStringLiteral("hh:mm")), m_locale.toString(endDateTime, QStringLiteral("hh:mm")));
     }
 
     return QString();
@@ -513,7 +506,7 @@ QString IncidenceModel::displayStartDate(const int idx) const
     auto incidence = m_incidences.at(idx);
 
     if (incidence->dtStart().isValid()) {
-        return m_locale.toString(incidence->dtStart().toTimeZone(QTimeZone::systemTimeZone()).date(), "MMM d");
+        return m_locale.toString(incidence->dtStart().toTimeZone(QTimeZone::systemTimeZone()).date(), QStringLiteral("MMM d"));
     }
 
     return QString();
@@ -524,7 +517,7 @@ QString IncidenceModel::displayDueDate(const int idx) const
     auto incidence = m_incidences.at(idx);
 
     if ((incidence->type() == IncidenceBase::TypeTodo) && (incidence.dynamicCast<Todo>()->dtDue().isValid())) {
-        return m_locale.toString(incidence.dynamicCast<Todo>()->dtDue().toTimeZone(QTimeZone::systemTimeZone()).date(), "MMM d");
+        return m_locale.toString(incidence.dynamicCast<Todo>()->dtDue().toTimeZone(QTimeZone::systemTimeZone()).date(), QStringLiteral("MMM d"));
     }
 
     return i18n("No Due Date");
@@ -540,7 +533,7 @@ QString IncidenceModel::displayDueTime(const int idx) const
 
     if (incidence->type() == IncidenceBase::TypeTodo) {
         auto todo = incidence.dynamicCast<Todo>();
-        return todo->dtDue().isValid() ? m_locale.toString(todo->dtDue().toTimeZone(QTimeZone::systemTimeZone()).time(), "hh:mm") : QString();
+        return todo->dtDue().isValid() ? m_locale.toString(todo->dtDue().toTimeZone(QTimeZone::systemTimeZone()).time(), QStringLiteral("hh:mm")) : QString();
     }
 
     return QString();
@@ -555,7 +548,7 @@ QString IncidenceModel::displayStartTime(const int idx) const
         return i18n("all-day");
     }
 
-    return startDt.isValid() ? m_locale.toString(startDt.time(), "hh:mm") : QString();
+    return startDt.isValid() ? m_locale.toString(startDt.time(), QStringLiteral("hh:mm")) : QString();
 }
 
 void IncidenceModel::setAppLocale(const QLocale &qmlLocale)
